@@ -18,7 +18,8 @@
 #  pragma warning (disable :4127) // conditional expression is constant.
 #endif
 
-#include <boost/test/test_exec_monitor.hpp> // Boost.Test
+#define BOOST_TEST_MAIN
+#include <boost/test/unit_test.hpp> // Boost.Test
 #include <boost/test/floating_point_comparison.hpp>
 
 #include <boost/math/concepts/real_concept.hpp> // for real_concept
@@ -690,7 +691,7 @@ void test_spots(RealType)
 
 } // template <class RealType>void test_spots(RealType)
 
-int test_main(int, char* [])
+BOOST_AUTO_TEST_CASE( test_main )
 {
   // Check that can construct students_t distribution using the two convenience methods:
   using namespace boost::math;
@@ -715,8 +716,8 @@ int test_main(int, char* [])
 #endif
 
 
-   return 0;
-} // int test_main(int, char* [])
+   
+} // BOOST_AUTO_TEST_CASE( test_main )
 
 /*
 
